library(autopls)
library(gplots)
library(RColorBrewer)
library(reshape2)
library(viridis)

#setwd
setwd("Z:/SRER/Martha/NEONpaper/3x3buff")

#load ref data for all plant clip locations
data <- read.csv("foliarNref_wSRER.csv")
str(data[,c(1:13)])

#rename columns from band# to wavelength
ref <- data[,12:437]
#create wavelengths for bands
lambda <- seq(385,2510, by=5)
lambda <- sub("$", "nm", lambda) 
colnames(ref) <- lambda
#shortest, longest, and water abosrption bands as NA
ref[,1:5] <- NA
ref[,191:215] <- NA
ref[,283:324] <- NA
ref[,413:426] <- NA

#NDVI, RVI, and SAVI calculation. change formula at line 34
# --------------FNI output-----------------------
pb <- txtProgressBar(min = 2, max = 426, style = 3)
k=0
for (i in 1:426){
  band1 <- ref[,i]
  for (j in 1:426){
    band2 <- ref[,j]
    FNI <- (band1-band2)/(band1+band2)
    if(!is.na(FNI[1])){
      k <- k+1
      ref[,426+k] <- FNI
      band1name <- colnames(ref)[i]
      band2name <- colnames(ref)[j]
      colnames(ref)[426+k] <- paste(band1name, band2name, sep="-")
    }
    
    setTxtProgressBar(pb, i)
  }}


str(ref)
# remove all columns where all readings == 0 (ie- the columns where the same band is used for band1 and band2)
FNI <- ref[,427:116026]
FNI <- FNI[, colSums(FNI !=0, na.rm=TRUE) > 0] #this works for NDVI and SAVI calculation
  #for the RVI calculation do this instead:
  FNI <- FNI[vapply(FNI, function(x) length(unique(x[!is.na(x)]))>1, logical(1L))]

  #subset x biome
  regdata1 <- cbind(data$biome, FNI)
  names(regdata1)[1] <- "biome"
  regdata1 <- cbind(data$ntrgnPr, regdata1)
  names(regdata1)[1] <- "ntrgnPr"
  temperate <- subset(regdata1, biome== "temperate")
  arid <- subset(regdata1, biome== "arid")
  tropical <- subset(regdata1, biome== "tropical")
  continental <- subset(regdata1,biome== "boreal")

  FNI <- temperate[,-c(1:2)]
  foliarN <- temperate[,1]
  

#create empty matrix to store correlations
FNI_foliarN <- matrix(NA, nrow=ncol(FNI), ncol=1)

#perform calcualte FNI for each 2 band combination and create correlation matrix of FNI:FoliarN
pb <- txtProgressBar(min = 2, max = ncol(FNI), style = 3)

for (i in 1:ncol(FNI)){
    foliarNcor <- (cor(FNI[,i], foliarN, use="pairwise.complete.obs"))^2
    FNI_foliarN[i,] <- foliarNcor
    setTxtProgressBar(pb, i)
  }


FNI_foliarN <- as.data.frame(FNI_foliarN)

#cbind band1, band2, and avg coeff into a new df
FNIbandcombos <- read.csv("FNIbandcombos.csv")
rn <- as.character(FNIbandcombos$twoband)
twobands <- do.call(rbind, strsplit(rn, '-'))

dfvals <- cbind.data.frame(twobands,FNI_foliarN$V1)
names(dfvals)[names(dfvals) == "FNI_foliarN$V1"] <- "FNIcor"
names(dfvals)[names(dfvals) == "1"] <- "band1"
names(dfvals)[names(dfvals) == "2"] <- "band2"

#reshape data so that in corr matrix structure with band 1 as columns and band 2 as rows
hmdata <- acast(dfvals, band1~band2, value.var="FNIcor")
hmdata <- as.data.frame(hmdata)

#add the wavelength regions that were excluded
#create vector of excluded bands
lambda1 <- seq(385,405, by=5)
lambda2 <- seq(1335,1455, by=5)
lambda3 <- seq(1795,2000, by=5)
lambda4 <- seq(2445, 2510, by=5)
lambda <- c(lambda1, lambda2, lambda3, lambda4)
lambda <- sub("$", "nm", lambda) 
#add "NA" columns
colNAs <-matrix(NA, nrow=length(hmdata), ncol=length(lambda))
colnames(colNAs) <- lambda
hm1 <- cbind.data.frame(hmdata, colNAs)
#add "NA" rows
rowNAs <- matrix(NA, nrow=length(lambda), ncol=length(hm1))
rownames(rowNAs) <- lambda
colnames(rowNAs) <- colnames(hm1)
hm2 <- rbind.data.frame(hm1, rowNAs)

#reorder data in wavelength order
lamnum <- rownames(hm2)
lamnum <- sub("nm", "", lamnum)
lamnum <- as.numeric(lamnum)
#assign the numeric wavelength as column and row names
rownames(hm2) <- lamnum
colnames(hm2) <- lamnum
#order the df in decending wavelength order
new_df <- hm2[ order(as.numeric(row.names(hm2))), ]
new_df <- new_df[,order(as.numeric(colnames(new_df)))]

#Hide lower triangle
hmfinal<-new_df
hmfinal[upper.tri(new_df, diag=TRUE)]<-""
#convert to form needed for heatmap (numeric matrix)
#hmfinal<-data.matrix(hmfinal)
hmfinal <- as.matrix(sapply(hmfinal, as.numeric))
write.csv(hmfinal, "./RVI/heatmap/RVI_R2_tropical.csv")

#DO the HEAT MAP#
labvec <- c(rep(NA, 426))
labvec[c(4,44,84,124,164,204,244,284,324,364,404)] <- c(400,600,800,1000,1200,1400,1600,1800,2000,2200,2400)

#create color ramp for heat map
#redbluebrew <- colorRampPalette(brewer.pal(11,"RdBu"))(20)
inferno <- colorRampPalette(c("#fcffa4","#f98c0a", "#ba3655", "#550f6d", "#000004"))
lwid = c(1.5,4)
lhei = c(1.5,4)
#to put key underneath heatmap
lmat = rbind(4:3,2:1)

#create heat map of correlation coefficients for all 2-band indices
heatmap.2((hmfinal),dendrogram='none', Rowv=FALSE, na.rm=TRUE, distfun=FALSE,
          Colv=FALSE,trace='none', col=viridis, labRow=labvec, 
          labCol=labvec, srtCol=0, adjCol=c(0,-25),cexRow = 1.1, cexCol = 1.1,
          lmat = lmat, lwid = lwid, lhei = lhei, main="All Sites", breaks=seq(0,0.6, length.out=21),
          key=FALSE)
#for each ecosystem saved as .png image; width: 652 height: 471;
#labels:
heatmap.2((hmfinal),dendrogram='none', Rowv=FALSE, na.rm=TRUE, distfun=FALSE,
          Colv=FALSE,trace='none', col=inferno, labRow=labvec, 
          labCol=labvec, srtCol=0,cexRow = 1.1, cexCol = 1.1, offsetRow = -30,
          lmat = lmat, lwid = lwid, lhei = lhei, main="Tropical Sites",breaks=seq(0,0.6, length.out=21),
          key=TRUE, density.info="histogram",denscol = "black", key.title = NA,
          key.xlab = "Correlation of Foliar N to FNI, R2", key.ylab = "Count",
          xlab= "Wavelength Band 2 (nm)", ylab="Wavelength Band 1 (nm)")

#min(hmfinal, na.rm=TRUE)
max(hmfinal, na.rm=TRUE)
mean(hmfinal, na.rm=TRUE)
median(hmfinal, na.rm=TRUE)




