# code to create .shp files of herbaceous plant clips and woody samples. 
#First must dl the NDNI (Foliar N) data products from the NEON data portal 
###-- these provide the CRS information needed to georeference plant clip coords
#Also, must run 'plantclip_locations.R' to get coordinates of plant samples

library(raster)
library(ggplot2)
library(rgdal)
library(ggthemes)
library(multcompView)
library(colorspace)

#setwd
setwd("XXXXX")

#####load all NDNI NEON AOP products####
DEJU <- raster("AOPNDNI/DEJU/DEJU_foliarN.tif")
DSNY <- raster("AOPNDNI/DSNY/DSNY_foliarN.tif")
GUAN <- raster("AOPNDNI/GUAN/GUAN_foliarN.tif")
HARV <- raster("AOPNDNI/HARV/HARV_foliarN.tif")
JORN <- raster("AOPNDNI/JORN/JORN_foliarN.tif")
KONZ <- raster("AOPNDNI/KONZ/KONZ_foliarN.tif")
LENO <- raster("AOPNDNI/LENO/LENO_foliarN.tif")
MLBS <- raster("AOPNDNI/MLBS/MLBS_foliarN.tif")
MOAB <- raster("AOPNDNI/MOAB/MOAB_foliarN.tif")
OAES <- raster("AOPNDNI/OAES/OAES_foliarN.tif")
SCBI <- raster("AOPNDNI/SCBI/SCBI_foliarN.tif")
SOAP <- raster("AOPNDNI/SOAP/SOAP_foliarN.tif")
STEI_E <- raster("AOPNDNI/STEI/Eplots/STEI_foliarN.tif")
STEI_W <- raster("AOPNDNI/STEI/Wplots/STEI_foliarN.tif")
STER <- raster("AOPNDNI/STER/STER_foliarN.tif")
TALL <- raster("AOPNDNI/TALL/TALL_foliarN.tif")
TOOL <- raster("AOPNDNI/TOOL/TOOL_foliarN.tif")
UKFS <- raster("AOPNDNI/UKFS/UKFS_foliarN.tif")

#2019 samples#
CLBJ <- raster("AOPNDNI/CLBJ/CLBJ_foliarN.tif")
DELA <- raster("AOPNDNI/DELA/DELA_foliarN.tif")
PUUM <- raster("AOPNDNI/PUUM/PUUM_foliarN.tif")
SJER <- raster("AOPNDNI/SJER/SJER_foliarN.tif")
UNDE <- raster("AOPNDNI/UNDE/UNDE_foliarN.tif")
KONA <- raster("AOPNDNI/KONA/KONA_foliarN.tif")

#####load plant clip location files (output from 'plantclip_locations.R'#####
herbs <- read.csv("herbs_foliarchem_locations.csv")
woody <- read.csv("woody_foliarchem_locations.csv")
# remove observations that don't have re-calculated lat/long coordinates
herbs <- herbs[complete.cases(herbs[,27:28]),]
woody <- woody[complete.cases(woody[,20:21]),]

######subset each of the plant clip dataframes by siteID so that projections can be defined#####
herbs$siteID <- as.factor(herbs$siteID)
woody$siteID <- as.factor(woody$siteID)
summary(herbs$siteID)
summary(woody$siteID)

dsny_herb <- subset(herbs, siteID =="DSNY")
jorn_herb <- subset(herbs, siteID =="JORN")
konz_herb <- subset(herbs, siteID =="KONZ")
moab_herb <- subset(herbs, siteID =="MOAB")
oaes_herb <- subset(herbs, siteID =="OAES")
#ornl_herb <- subset(herbs, siteID =="ORNL")
scbi_herb <- subset(herbs, siteID =="SCBI")
#serc_herb <- subset(herbs, siteID =="SERC")
soap_herb <- subset(herbs, siteID =="SOAP")
ster_herb <- subset(herbs, siteID =="STER")
tool_herb <- subset(herbs, siteID =="TOOL")
ukfs_herb <- subset(herbs, siteID =="UKFS")
#wood_herb <- subset(herbs, siteID =="WOOD")
clbj_herb <- subset(herbs, siteID=="CLBJ")
sjer_herb <- subset(herbs, siteID=="SJER")
kona_herb <- subset(herbs, siteID=="KONA")

deju_wood <- subset(woody, siteID=="DEJU")
dsny_wood <- subset(woody, siteID=="DSNY")
#grsm_wood <- subset(woody, siteID=="GRSM")
guan_wood <- subset(woody, siteID=="GUAN")
harv_wood <- subset(woody, siteID=="HARV")
jorn_wood <- subset(woody, siteID=="JORN")
konz_wood <- subset(woody, siteID=="KONZ")
leno_wood <- subset(woody, siteID=="LENO")
mlbs_wood <- subset(woody, siteID=="MLBS")
moab_wood <- subset(woody, siteID=="MOAB")
#ornl_wood <- subset(woody, siteID=="ORNL")
scbi_wood <- subset(woody, siteID=="SCBI")
#serc_wood <- subset(woody, siteID=="SERC")
soap_wood <- subset(woody, siteID=="SOAP")
stei_wood <- subset(woody, siteID=="STEI")
tall_wood <- subset(woody, siteID=="TALL")
ukfs_wood <- subset(woody, siteID=="UKFS")
clbj_wood <- subset(woody, siteID=="CLBJ")
dela_wood <- subset(woody, siteID=="DELA")
puum_wood <- subset(woody, siteID=="PUUM")
sjer_wood <- subset(woody, siteID=="SJER")
unde_wood <- subset(woody, siteID=="UNDE")

#####convert plant clip location dataframes to spatialPoints object#####
##1.subset plant clip location dfs with x,y (northing and easting) coordinates
##2.define spatial coordinates to make a spatialPoints object 
##3.define projection of plant clip locations based on projection of the NDNI raster for that site
##steps 1-3 repeated for each site with both herb and woody plant samples.
dsny_herbxy <- dsny_herb
coordinates(dsny_herbxy)= ~ adjEasting + adjNorthing
proj4string(dsny_herbxy) <- proj4string(DSNY)
#raster::shapefile(dsny_herbxy, "./clip_locs/DSNYherb.shp")

jorn_herbxy <- jorn_herb
coordinates(jorn_herbxy)= ~ adjEasting + adjNorthing
proj4string(jorn_herbxy) <- proj4string(JORN)
#raster::shapefile(jorn_herbxy, "./clip_locs/JORNherb.shp")

konz_herbxy <- konz_herb
coordinates(konz_herbxy)= ~ adjEasting + adjNorthing
proj4string(konz_herbxy) <- proj4string(KONZ)
#raster::shapefile(konz_herbxy, "./clip_locs/KONZherb.shp")

moab_herbxy <- moab_herb
coordinates(moab_herbxy)= ~ adjEasting + adjNorthing
proj4string(moab_herbxy) <- proj4string(MOAB)
#raster::shapefile(moab_herbxy, "./clip_locs/MOABherb.shp")

oaes_herbxy <- oaes_herb
coordinates(oaes_herbxy)= ~ adjEasting + adjNorthing
proj4string(oaes_herbxy) <- proj4string(OAES)
#raster::shapefile(oaes_herbxy, "./clip_locs/OAESherb.shp")

#ornl_herbxy <- ornl_herb[,c(19,20)]
#coordinates(ornl_herbxy)= ~ easting + northing
#proj4string(ornl_herbxy) <- proj4string(ORNL)

scbi_herbxy <- scbi_herb
coordinates(scbi_herbxy)= ~ adjEasting + adjNorthing
proj4string(scbi_herbxy) <- proj4string(SCBI)
#raster::shapefile(scbi_herbxy, "./clip_locs/SCBIherb.shp")

#serc_herbxy <- serc_herb[,c(19,20)]
#coordinates(serc_herbxy)= ~ easting + northing
#proj4string(serc_herbxy) <- proj4string(SERC)

soap_herbxy <- soap_herb
coordinates(soap_herbxy)= ~ adjEasting + adjNorthing
proj4string(soap_herbxy) <- proj4string(SOAP)
#raster::shapefile(soap_herbxy, "./clip_locs/SOAPherb.shp")

ster_herbxy <- ster_herb
coordinates(ster_herbxy)= ~ adjEasting + adjNorthing
proj4string(ster_herbxy) <- proj4string(STER)
#raster::shapefile(ster_herbxy, "./clip_locs/STERherb.shp")

tool_herbxy <- tool_herb
coordinates(tool_herbxy)= ~ adjEasting + adjNorthing
proj4string(tool_herbxy) <- proj4string(TOOL)
#raster::shapefile(tool_herbxy, "./clip_locs/TOOLherb.shp")

ukfs_herbxy <- ukfs_herb
coordinates(ukfs_herbxy)= ~ adjEasting + adjNorthing
proj4string(ukfs_herbxy) <- proj4string(UKFS)
#raster::shapefile(ukfs_herbxy, "./clip_locs/UKFSherb.shp")

#wood_herbxy <- wood_herb[,c(19,20)]
#coordinates(wood_herbxy)= ~ easting + northing
#proj4string(wood_herbxy) <- proj4string(WOOD)

clbj_herbxy <- clbj_herb
coordinates(clbj_herbxy)= ~ adjEasting + adjNorthing
proj4string(clbj_herbxy) <- proj4string(CLBJ)

sjer_herbxy <- sjer_herb
coordinates(sjer_herbxy)= ~ adjEasting + adjNorthing
proj4string(sjer_herbxy) <- proj4string(SJER)

kona_herbxy <- kona_herb
coordinates(kona_herbxy)= ~ adjEasting + adjNorthing
proj4string(kona_herbxy) <- proj4string(KONA)

#-------------WOODY SAMPLES-----------#
#woody samples
deju_woodxy <- deju_wood
coordinates(deju_woodxy)= ~ adjEasting + adjNorthing
proj4string(deju_woodxy) <- proj4string(DEJU)
#raster::shapefile(deju_woodxy, "./clip_locs/DEJUwood.shp")

dsny_woodxy <- dsny_wood
coordinates(dsny_woodxy)= ~ adjEasting + adjNorthing
proj4string(dsny_woodxy) <- proj4string(DSNY)
#raster::shapefile(dsny_woodxy, "./clip_locs/DSNYwood.shp")

#grsm_woodxy <- grsm_wood[,c(16,17)]
#coordinates(grsm_woodxy)= ~ adjEasting + adjNorthing
#proj4string(grsm_woodxy) <- proj4string(GRSM)

guan_woodxy <- guan_wood
coordinates(guan_woodxy)= ~ adjEasting + adjNorthing
proj4string(guan_woodxy) <- proj4string(GUAN)
#raster::shapefile(guan_woodxy, "./clip_locs/GUANwood.shp")

harv_woodxy <- harv_wood
coordinates(harv_woodxy)= ~ adjEasting + adjNorthing
proj4string(harv_woodxy) <- proj4string(HARV)
#raster::shapefile(harv_woodxy, "./clip_locs/HARVwood.shp")

jorn_woodxy <- jorn_wood
coordinates(jorn_woodxy)= ~ adjEasting + adjNorthing
proj4string(jorn_woodxy) <- proj4string(JORN)
#raster::shapefile(jorn_woodxy, "./clip_locs/JORNwood.shp")

konz_woodxy <- konz_wood
coordinates(konz_woodxy)= ~ adjEasting + adjNorthing
proj4string(konz_woodxy) <- proj4string(KONZ)
raster::shapefile(konz_woodxy, "./clip_locs/KONZwood.shp")

leno_woodxy <- leno_wood
coordinates(leno_woodxy)= ~ adjEasting + adjNorthing
proj4string(leno_woodxy) <- proj4string(LENO)
#raster::shapefile(leno_woodxy, "./clip_locs/LENOwood.shp")

mlbs_woodxy <- mlbs_wood
coordinates(mlbs_woodxy)= ~ adjEasting + adjNorthing
proj4string(mlbs_woodxy) <- proj4string(MLBS)
#raster::shapefile(mlbs_woodxy, "./clip_locs/MLBSwood.shp")

moab_woodxy <- moab_wood
coordinates(moab_woodxy)= ~ adjEasting + adjNorthing
proj4string(moab_woodxy) <- proj4string(MOAB)
#raster::shapefile(moab_woodxy, "./clip_locs/MOABwood.shp")

#ornl_woodxy <- ornl_wood[,c(16,17)]
#coordinates(ornl_woodxy)= ~ adjEasting + adjNorthing
#proj4string(ornl_woodxy) <- proj4string(ORNL)

scbi_woodxy <- scbi_wood
coordinates(scbi_woodxy)= ~ adjEasting + adjNorthing
proj4string(scbi_woodxy) <- proj4string(SCBI)
#raster::shapefile(scbi_woodxy, "./clip_locs/SCBIwood.shp")

#serc_woodxy <- serc_wood[,c(16,17)]
#coordinates(serc_woodxy)= ~ adjEasting + adjNorthing
#proj4string(serc_woodxy) <- proj4string(SERC)

soap_woodxy <- soap_wood
coordinates(soap_woodxy)= ~ adjEasting + adjNorthing
proj4string(soap_woodxy) <- proj4string(SOAP)
#raster::shapefile(soap_woodxy, "./clip_locs/SOAPwood.shp")

stei_woodE <- subset(stei_wood, utmZone== "16N")
stei_woodW <- subset(stei_wood, utmZone== "15N")
stei_woodExy <- stei_woodE
coordinates(stei_woodExy)= ~ adjEasting + adjNorthing
proj4string(stei_woodExy) <- proj4string(STEI_E)
#raster::shapefile(stei_woodExy, "./clip_locs/STEI_Ewood.shp")
stei_woodWxy <- stei_woodW
coordinates(stei_woodWxy)= ~ adjEasting + adjNorthing
proj4string(stei_woodWxy) <- proj4string(STEI_W)
#raster::shapefile(stei_woodWxy, "./clip_locs/STEI_Wwood.shp")

tall_woodxy <- tall_wood
coordinates(tall_woodxy)= ~ adjEasting + adjNorthing
proj4string(tall_woodxy) <- proj4string(TALL)
#raster::shapefile(tall_woodxy, "./clip_locs/TALLwood.shp")

ukfs_woodxy <- ukfs_wood
coordinates(ukfs_woodxy)= ~ adjEasting + adjNorthing
proj4string(ukfs_woodxy) <- proj4string(UKFS)
#raster::shapefile(ukfs_woodxy, "./clip_locs/UKFSwood.shp")

clbj_woodxy <- clbj_wood
coordinates(clbj_woodxy)= ~ adjEasting + adjNorthing
proj4string(clbj_woodxy) <- proj4string(CLBJ)

dela_woodxy <- dela_wood
coordinates(dela_woodxy)= ~ adjEasting + adjNorthing
proj4string(dela_woodxy) <- proj4string(DELA)

puum_woodxy <- puum_wood
coordinates(puum_woodxy)= ~ adjEasting + adjNorthing
proj4string(puum_woodxy) <- proj4string(PUUM)

sjer_woodxy <- sjer_wood
coordinates(sjer_woodxy)= ~ adjEasting + adjNorthing
proj4string(sjer_woodxy) <- proj4string(SJER)

unde_woodxy <- unde_wood
coordinates(unde_woodxy)= ~ adjEasting + adjNorthing
proj4string(unde_woodxy) <- proj4string(UNDE)


#####extract herbaceous plant sample AOP NDNI (Foliar N) values for all sites######
DSNYherbs <- raster::extract(DSNY, dsny_herbxy, df=T, buffer=2, fun=mean)
DSNYherbs$clipID <- dsny_herb$clipID
DSNYherbs <- DSNYherbs[complete.cases(DSNYherbs),]
names(DSNYherbs) <- c('ID', 'foliarN', 'clipID')

JORNherbs <- raster::extract(JORN, jorn_herbxy, df=T, buffer=2, fun=mean)
JORNherbs$clipID <- jorn_herb$clipID
JORNherbs <- JORNherbs[complete.cases(JORNherbs),]
names(JORNherbs) <- c('ID', 'foliarN', 'clipID')

AOPherbs <- rbind(DSNYherbs,JORNherbs)
oldAOP <- AOPherbs

KONZherbs <- raster::extract(KONZ, konz_herbxy, df=T, buffer=2, fun=mean)
KONZherbs$clipID <- konz_herb$clipID
KONZherbs <- KONZherbs[complete.cases(KONZherbs),]
names(KONZherbs) <- c('ID', 'foliarN', 'clipID')

AOPherbs <- rbind(oldAOP,KONZherbs)
oldAOP <- AOPherbs

MOABherbs <- raster::extract(MOAB, moab_herbxy, df=T, buffer=2, fun=mean)
MOABherbs$clipID <- moab_herb$clipID
MOABherbs <- MOABherbs[complete.cases(MOABherbs),]
names(MOABherbs) <- c('ID', 'foliarN', 'clipID')

AOPherbs <- rbind(oldAOP,MOABherbs)
oldAOP <- AOPherbs

OAESherbs <- raster::extract(OAES, oaes_herbxy, df=T, buffer=2, fun=mean)
OAESherbs$clipID <- oaes_herb$clipID
OAESherbs <- OAESherbs[complete.cases(OAESherbs),]
names(OAESherbs) <- c('ID', 'foliarN', 'clipID')

AOPherbs <- rbind(oldAOP,OAESherbs)
oldAOP <- AOPherbs

SCBIherbs <- raster::extract(SCBI, scbi_herbxy, df=T, buffer=2, fun=mean)
SCBIherbs$clipID <- scbi_herb$clipID
SCBIherbs <- SCBIherbs[complete.cases(SCBIherbs),]
names(SCBIherbs) <- c('ID', 'foliarN', 'clipID')

AOPherbs <- rbind(oldAOP,SCBIherbs)
oldAOP <- AOPherbs

SOAPherbs <- raster::extract(SOAP, soap_herbxy, df=T, buffer=2, fun=mean)
SOAPherbs$clipID <- soap_herb$clipID
SOAPherbs <- SOAPherbs[complete.cases(SOAPherbs),]
names(SOAPherbs) <- c('ID', 'foliarN', 'clipID')

AOPherbs <- rbind(oldAOP,SOAPherbs)
oldAOP <- AOPherbs

STERherbs <- raster::extract(STER, ster_herbxy, df=T, buffer=2, fun=mean)
STERherbs$clipID <- ster_herb$clipID
STERherbs <- STERherbs[complete.cases(STERherbs),]
names(STERherbs) <- c('ID', 'foliarN', 'clipID')

AOPherbs <- rbind(oldAOP,STERherbs)
oldAOP <- AOPherbs

TOOLherbs <- raster::extract(TOOL, tool_herbxy, df=T, buffer=2, fun=mean)
TOOLherbs$clipID <- tool_herb$clipID
TOOLherbs <- TOOLherbs[complete.cases(TOOLherbs),]
names(TOOLherbs) <- c('ID', 'foliarN', 'clipID')

AOPherbs <- rbind(oldAOP,TOOLherbs)
oldAOP <- AOPherbs

UKFSherbs <- raster::extract(UKFS, ukfs_herbxy, df=T, buffer=2, fun=mean)
UKFSherbs$clipID <- ukfs_herb$clipID
UKFSherbs <- UKFSherbs[complete.cases(UKFSherbs),]
names(UKFSherbs) <- c('ID', 'foliarN', 'clipID')

AOPherbs <- rbind(oldAOP,UKFSherbs)
oldAOP <- AOPherbs

CLBJherbs <- raster::extract(CLBJ, clbj_herbxy, df=T, buffer=2, fun=mean)
CLBJherbs$clipID <- clbj_herb$clipID
CLBJherbs <- CLBJherbs[complete.cases(CLBJherbs),]
names(CLBJherbs) <- c('ID', 'foliarN', 'clipID')

AOPherbs <- rbind(oldAOP,CLBJherbs)
oldAOP <- AOPherbs

SJERherbs <- raster::extract(SJER, sjer_herbxy, df=T, buffer=2, fun=mean)
SJERherbs$clipID <- sjer_herb$clipID
SJERherbs <- SJERherbs[complete.cases(SJERherbs),]
names(SJERherbs) <- c('ID', 'foliarN', 'clipID')

AOPherbs <- rbind(oldAOP,SJERherbs)
oldAOP <- AOPherbs

KONAherbs <- raster::extract(KONA, kona_herbxy, df=T, buffer=2, fun=mean)
KONAherbs$clipID <- kona_herb$clipID
KONAherbs <- KONAherbs[complete.cases(KONAherbs),]
names(KONAherbs) <- c('ID', 'foliarN', 'clipID')

AOPherbs <- rbind(oldAOP,KONAherbs)

herbs_AOPN <- merge(AOPherbs,herbs, by="clipID")
#write.csv(herbs_AOPN, "./data/dataSept2020/herbs_NDNI.csv")

#####extract woody plant sample AOP NDNI (Foliar N) values for all sites######
DEJUwood <- raster::extract(DEJU, deju_woodxy, df=T)
DEJUwood$individualID <-  deju_wood$individualID
DEJUwood <- DEJUwood[complete.cases(DEJUwood),]
names(DEJUwood) <- c('ID', 'NDNI', 'individualID')

DSNYwood <- raster::extract(DSNY, dsny_woodxy, df=T)
DSNYwood$individualID <-  dsny_wood$individualID
DSNYwood <- DSNYwood[complete.cases(DSNYwood),]
names(DSNYwood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(DEJUwood,DSNYwood)
oldAOP <- AOPwood

GUANwood <- raster::extract(GUAN, guan_woodxy, df=T)
GUANwood$individualID <-  guan_wood$individualID
GUANwood <- GUANwood[complete.cases(GUANwood),]
names(GUANwood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,GUANwood)
oldAOP <- AOPwood

HARVwood <- raster::extract(HARV, harv_woodxy, df=T)
HARVwood$individualID <-  harv_wood$individualID
HARVwood <- HARVwood[complete.cases(HARVwood),]
names(HARVwood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,HARVwood)
oldAOP <- AOPwood

JORNwood <- raster::extract(JORN, jorn_woodxy, df=T)
JORNwood$individualID <-  jorn_wood$individualID
JORNwood <- JORNwood[complete.cases(JORNwood),]
names(JORNwood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,JORNwood)
oldAOP <- AOPwood

KONZwood <- raster::extract(KONZ, konz_woodxy, df=T)
KONZwood$individualID <- konz_wood$individualID
KONZwood <- KONZwood[complete.cases(KONZwood),]
names(KONZwood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,KONZwood)
oldAOP <- AOPwood

LENOwood <- raster::extract(LENO, leno_woodxy, df=T)
LENOwood$individualID <- leno_wood$individualID
LENOwood <- LENOwood[complete.cases(LENOwood),]
names(LENOwood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,LENOwood)
oldAOP <- AOPwood

MLBSwood <- raster::extract(MLBS, mlbs_woodxy, df=T)
MLBSwood$individualID <- mlbs_wood$individualID
MLBSwood <- MLBSwood[complete.cases(MLBSwood),]
names(MLBSwood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,MLBSwood)
oldAOP <- AOPwood

MOABwood <- raster::extract(MOAB, moab_woodxy, df=T)
MOABwood$individualID <- moab_wood$individualID
MOABwood <- MOABwood[complete.cases(MOABwood),]
names(MOABwood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,MOABwood)
oldAOP <- AOPwood

SCBIwood <- raster::extract(SCBI, scbi_woodxy, df=T)
SCBIwood$individualID <- scbi_wood$individualID
SCBIwood <- SCBIwood[complete.cases(SCBIwood),]
names(SCBIwood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,SCBIwood)
oldAOP <- AOPwood

SOAPwood <- raster::extract(SOAP, soap_woodxy, df=T)
SOAPwood$individualID <- soap_wood$individualID
SOAPwood <- SOAPwood[complete.cases(SOAPwood),]
names(SOAPwood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,SOAPwood)
oldAOP <- AOPwood

STEI_Ewood <- raster::extract(STEI_E, stei_woodExy, df=T)
STEI_Ewood$individualID <- stei_woodE$individualID
STEI_Ewood <- STEI_Ewood[complete.cases(STEI_Ewood),]
names(STEI_Ewood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,STEI_Ewood)
oldAOP <- AOPwood

STEI_Wwood <- raster::extract(STEI_W, stei_woodWxy, df=T)
STEI_Wwood$individualID <- stei_woodW$individualID
STEI_Wwood <- STEI_Wwood[complete.cases(STEI_Wwood),]
names(STEI_Wwood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,STEI_Wwood)
oldAOP <- AOPwood

TALL_wood <- raster::extract(TALL, tall_woodxy, df=T)
TALL_wood$individualID <- tall_wood$individualID
TALL_wood <- TALL_wood[complete.cases(TALL_wood),]
names(TALL_wood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,TALL_wood)
oldAOP <- AOPwood

UKFS_wood <- raster::extract(UKFS, ukfs_woodxy, df=T)
UKFS_wood$individualID <- ukfs_wood$individualID
UKFS_wood <- UKFS_wood[complete.cases(UKFS_wood),]
names(UKFS_wood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,UKFS_wood)
oldAOP <- AOPwood

CLBJ_wood <- raster::extract(CLBJ, clbj_woodxy, df=T)
CLBJ_wood$individualID <- clbj_wood$individualID
CLBJ_wood <- CLBJ_wood[complete.cases(CLBJ_wood),]
names(CLBJ_wood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,CLBJ_wood)
oldAOP <- AOPwood

DELA_wood <- raster::extract(DELA, dela_woodxy, df=T)
DELA_wood$individualID <- dela_wood$individualID
DELA_wood <- DELA_wood[complete.cases(DELA_wood),]
names(DELA_wood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,DELA_wood)
oldAOP <- AOPwood

PUUM_wood <- raster::extract(PUUM, puum_woodxy, df=T)
PUUM_wood$individualID <- puum_wood$individualID
PUUM_wood <- PUUM_wood[complete.cases(PUUM_wood),]
names(PUUM_wood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,PUUM_wood)
oldAOP <- AOPwood

SJER_wood <- raster::extract(SJER, sjer_woodxy, df=T)
SJER_wood$individualID <- sjer_wood$individualID
SJER_wood <- SJER_wood[complete.cases(SJER_wood),]
names(SJER_wood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,SJER_wood)
oldAOP <- AOPwood

UNDE_wood <- raster::extract(UNDE, unde_woodxy, df=T)
UNDE_wood$individualID <- unde_wood$individualID
UNDE_wood <- UNDE_wood[complete.cases(UNDE_wood),]
names(UNDE_wood) <- c('ID', 'NDNI', 'individualID')

AOPwood <- rbind(oldAOP,UNDE_wood)

woody_AOPN <- merge(AOPwood, woody, by="individualID")


library(dplyr)
# remove duplicate values wherever they exist. take means for numeric variables, else first observation. 
ndniwoody <- woody_AOPN  %>%
  group_by(individualID) %>%
  summarise_all(list( ~ if (is.numeric(.)) {
    mean(., na.rm = TRUE)
  } else {
    first(.)
  }))

#write.csv(ndniwoody, "./data/dataSept2020/woody_NDNI.csv")

#delete the extra columns in the datasets
woody <- woody[,c(1:3,5:23)]
herbs <- herbs[,c(1:20, 26:30)]
#rename  columns
names(herbs)[names(herbs) == "foliarN"] <- "NDNI"
#add extra columns to match up between the 2 datasets
woody$clipLength <- NA
woody$clipWidth <- NA
woody$percentCoverClip <- NA

#subset herb clips so that %cover is >= 85%
highcov <- subset(herbs, percentCoverClip >= 85)

#combine the woody and herbaceous samples into a single df
regdata <- rbind(woody,highcov)

#WRITE DATA
write.csv(regdata,"./data/dataSept2020/foliarchem_locs_allsites.csv")

#######create a shp file of the regression data##############
plantlocs <- regdata
coordinates(plantlocs) = ~ adjEasting + adjNorthing
proj4string(plantlocs)<- CRS("+proj=utm +datum=WGS84 +units=m +nodefs") # set coordinate system to WGS
raster::shapefile(plantlocs, "./data/dataSept2020/shp_files/alllocs_greater85.shp", overwrite=TRUE)

#subset for each utmzone
zone <- subset(regdata, utmZone=="19N")
coordinates(zone) = ~ adjEasting + adjNorthing
proj4string(zone)<- CRS("+proj=utm +zone=19 +datum=WGS84 +units=m +nodefs") # set coordinate system to WGS
raster::shapefile(zone, "Z:/SRER/Martha/NEONpaper/data/dataSept2020/shp_files/zone19N.shp", overwrite=TRUE)
